# Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""aws.aws-tasks-mcp-server"""

__version__ = '0.0.0'


# Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Placeholder package - not operational."""

import warnings
import sys


def _show_placeholder_warning():
    """Display placeholder warning message."""
    message = "this is a non-operational placeholder package"
    print(f"WARNING: {message}", file=sys.stderr)
    warnings.warn(message, UserWarning, stacklevel=2)


# Execute warning on import
_show_placeholder_warning()


def __getattr__(name):
    """Override attribute access to show warnings."""
    _show_placeholder_warning()
    raise AttributeError(f"'{__name__}' is a non-operational placeholder package and has no attribute '{name}'")


# Package metadata
__version__ = "0.0.0"
__author__ = "AWS Labs"
__email__ = "203918161+awslabs-mcp@users.noreply.github.com"
__license__ = "Apache-2.0"
